Crate ws6in1_proto

Crate ws6in1_proto 

ws6in1-proto

A Rust crate that provides a CC8488 compatible weather station protocol implementation.

Crate Features and Goals

  • High level client for easy integration into applications.
  • Optional no_std support for embedded devices.
  • Verify messages during de-serialization.
  • Being efficient if possible.

Rust Feature Flags

  • std (default) — Remove this feature to make the library no_std compatible.
  • client — Enables an async-hid based high level client.
  • heapless - Enables support for heapless vectors.

Device access

To access the USB hidraw device on Linux it may be required to install the supplied udev rules and add the user to the dialout group.

Specification

License

ws6in1-proto is licensed under the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

Modules

client
High level async-hid based SMA speedwire client.
parser
Ws6in1 message parser. Data is parsed through TryFrom.
protocol
Low-level Ws6in1 protocol implementation.

Enums

Error
Errors returned from Ws6in1 protocol processing.

Traits

Ws6in1Container
Interface to a variable length storage container.

Type Aliases

Result
A specialized Result type for Ws6in1 operations.